@@ -63,33 +63,41 @@ func (a *Manager) Create(addon *api.Addon, wait bool) error {
 			logger.Info("using provided ServiceAccountRoleARN %q", addon.ServiceAccountRoleARN)
 			createAddonInput.ServiceAccountRoleArn = &addon.ServiceAccountRoleARN
 		} else if hasPoliciesSet(addon) {
-			outputRole, err := a.createRole(addon, namespace, serviceAccount)
-			if err != nil {
-				return err
-			}
-			createAddonInput.ServiceAccountRoleArn = &outputRole
-		} else if a.hasRecommendedPolicies(addon) {
-			logger.Info("creating role using recommended policies")
-			attachPolicyARNs, wellKnownPolicies := a.getRecommendedPolicies(addon)
-
-			if attachPolicyARNs != nil {
-				addon.AttachPolicyARNs = attachPolicyARNs
-			}
-			if wellKnownPolicies != nil {
-				addon.WellKnownPolicies = *wellKnownPolicies
-			}
-
 			outputRole, err := a.createRole(addon, namespace, serviceAccount)
 			if err != nil {
 				return err
 			}
 			createAddonInput.ServiceAccountRoleArn = &outputRole
 		} else {
-			logger.Info("no recommended policies found, proceeding without any IAM")
+			policyDocument, policyARNs, wellKnownPolicies := a.getRecommendedPolicies(addon)
+			if len(policyARNs) != 0 || policyDocument != nil || wellKnownPolicies != nil {
+				logger.Info("creating role using recommended policies")
+				addon.AttachPolicyARNs = policyARNs
+				addon.AttachPolicy = policyDocument
+				resourceSet := builder.NewIAMRoleResourceSetWithAttachPolicy(addon.Name, namespace, serviceAccount, addon.PermissionsBoundary, addon.AttachPolicy, a.oidcManager)
+				if len(policyARNs) != 0 {
+					resourceSet = builder.NewIAMRoleResourceSetWithAttachPolicyARNs(addon.Name, namespace, serviceAccount, addon.PermissionsBoundary, addon.AttachPolicyARNs, a.oidcManager)
+				}
+				if wellKnownPolicies != nil {
+					addon.WellKnownPolicies = *wellKnownPolicies
+					resourceSet = builder.NewIAMRoleResourceSetWithWellKnownPolicies(addon.Name, namespace, serviceAccount, addon.PermissionsBoundary, addon.WellKnownPolicies, a.oidcManager)
+				}
+				if err := resourceSet.AddAllResources(); err != nil {
+					return err
+				}
+				err := a.createStack(resourceSet, addon)
+				if err != nil {
+					return err
+				}
+				createAddonInput.ServiceAccountRoleArn = &resourceSet.OutputRole
+			} else {
+				logger.Info("no recommended policies found, proceeding without any IAM")
+			}
 		}
 	} else {
 		//if any sort of policy is set or could be set, log a warning
-		if addon.ServiceAccountRoleARN != "" || hasPoliciesSet(addon) || a.hasRecommendedPolicies(addon) {
+		policyDocument, policyARNs, wellKnownPolicies := a.getRecommendedPolicies(addon)
+		if addon.ServiceAccountRoleARN != "" || hasPoliciesSet(addon) || len(policyARNs) != 0 || policyDocument != nil || wellKnownPolicies != nil {
 			logger.Warning("OIDC is disabled but policies are required/specified for this addon. Users are responsible for attaching the policies to all nodegroup roles")
 		}
 	}
@@ -182,22 +190,21 @@ func (a *Manager) patchAWSNodeDaemonSet() error {
 	return nil
 }
 
-func (a *Manager) hasRecommendedPolicies(addon *api.Addon) bool {
-	attachPolicyARNs, wellKnownPolicies := a.getRecommendedPolicies(addon)
-	return attachPolicyARNs != nil || wellKnownPolicies != nil
-}
-
-func (a *Manager) getRecommendedPolicies(addon *api.Addon) ([]string, *api.WellKnownPolicies) {
+func (a *Manager) getRecommendedPolicies(addon *api.Addon) (api.InlineDocument, []string, *api.WellKnownPolicies) {
 	// API isn't case sensitive
 	switch addon.CanonicalName() {
 	case vpcCNIName:
-		return []string{fmt.Sprintf("arn:%s:iam::aws:policy/%s", api.Partition(a.clusterConfig.Metadata.Region), api.IAMPolicyAmazonEKSCNIPolicy)}, nil
+		if a.clusterConfig.KubernetesNetworkConfig != nil && a.clusterConfig.KubernetesNetworkConfig.IPFamily == api.IPV6Family {
+			return makeIPv6VPCCNIPolicyDocument(), nil, nil
+		}
+		return nil, []string{fmt.Sprintf("arn:%s:iam::aws:policy/%s", api.Partition(a.clusterConfig.Metadata.Region), api.IAMPolicyAmazonEKSCNIPolicy)}, nil
 	case ebsCSIDriverName:
-		return nil, &api.WellKnownPolicies{
+		return nil, nil, &api.WellKnownPolicies{
 			EBSCSIController: true,
 		}
+	default:
+		return nil, nil, nil
 	}
-	return nil, nil
 }
 
 func (a *Manager) getKnownServiceAccountLocation(addon *api.Addon) (string, string) {
@@ -258,3 +265,29 @@ func (a *Manager) createStack(resourceSet builder.ResourceSet, addon *api.Addon)
 
 	return <-errChan
 }
+
+func makeIPv6VPCCNIPolicyDocument() map[string]interface{} {
+	return map[string]interface{}{
+		"Version": "2012-10-17",
+		"Statement": []map[string]interface{}{
+			{
+				"Effect": "Allow",
+				"Action": []string{
+					"ec2:AssignIpv6Addresses",
+					"ec2:DescribeInstances",
+					"ec2:DescribeTags",
+					"ec2:DescribeNetworkInterfaces",
+					"ec2:DescribeInstanceTypes",
+				},
+				"Resource": "*",
+			},
+			{
+				"Effect": "Allow",
+				"Action": []string{
+					"ec2:CreateTags",
+				},
+				"Resource": "arn:aws:ec2:*:*:network-interface/*",
+			},
+		},
+	}
+}
