@@ -32,9 +32,14 @@ var _ = Describe("Create", func() {
 		returnedErr            error
 		createStackReturnValue error
 		rawClient              *testutils.FakeRawClient
+		clusterConfig          *api.ClusterConfig
 	)
 
 	BeforeEach(func() {
+		clusterConfig = &api.ClusterConfig{Metadata: &api.ClusterMeta{
+			Version: "1.18",
+			Name:    "my-cluster",
+		}}
 		withOIDC = true
 		returnedErr = nil
 		fakeStackManager = new(fakes.FakeStackManager)
@@ -81,10 +86,7 @@ var _ = Describe("Create", func() {
 			createAddonInput = args[0].(*awseks.CreateAddonInput)
 		}).Return(nil, returnedErr)
 
-		manager, err = addon.New(&api.ClusterConfig{Metadata: &api.ClusterMeta{
-			Version: "1.18",
-			Name:    "my-cluster",
-		}}, mockProvider.EKS(), fakeStackManager, withOIDC, oidc, rawClient.ClientSet(), 5*time.Minute)
+		manager, err = addon.New(clusterConfig, mockProvider.EKS(), fakeStackManager, withOIDC, oidc, rawClient.ClientSet(), 5*time.Minute)
 		Expect(err).NotTo(HaveOccurred())
 		manager.SetTimeout(time.Second)
 
@@ -393,33 +395,66 @@ var _ = Describe("Create", func() {
 
 			})
 
-			When("its the vpc-cni addon", func() {
-				It("creates a role with the recommended policies and attaches it to the addon", func() {
-					err := manager.Create(&api.Addon{
-						Name:    "vpc-cni",
-						Version: "v1.0.0-eksbuild.1",
-					}, false)
-					Expect(err).NotTo(HaveOccurred())
+			When("it's the vpc-cni addon", func() {
+				Context("ipv4", func() {
+					It("creates a role with the recommended policies and attaches it to the addon", func() {
+						err := manager.Create(&api.Addon{
+							Name:    "vpc-cni",
+							Version: "v1.0.0-eksbuild.1",
+						}, false)
+						Expect(err).NotTo(HaveOccurred())
 
-					Expect(fakeStackManager.CreateStackCallCount()).To(Equal(1))
-					name, resourceSet, tags, _, _ := fakeStackManager.CreateStackArgsForCall(0)
-					Expect(name).To(Equal("eksctl-my-cluster-addon-vpc-cni"))
-					Expect(resourceSet).NotTo(BeNil())
-					Expect(tags).To(Equal(map[string]string{
-						api.AddonNameTag: "vpc-cni",
-					}))
-					output, err := resourceSet.RenderJSON()
-					Expect(err).NotTo(HaveOccurred())
-					Expect(string(output)).To(ContainSubstring("arn:aws:iam::aws:policy/AmazonEKS_CNI_Policy"))
-					Expect(string(output)).To(ContainSubstring(":sub\":\"system:serviceaccount:kube-system:aws-node"))
-					Expect(*createAddonInput.ClusterName).To(Equal("my-cluster"))
-					Expect(*createAddonInput.AddonName).To(Equal("vpc-cni"))
-					Expect(*createAddonInput.AddonVersion).To(Equal("v1.0.0-eksbuild.1"))
-					Expect(*createAddonInput.ServiceAccountRoleArn).To(Equal("role-arn"))
+						Expect(fakeStackManager.CreateStackCallCount()).To(Equal(1))
+						name, resourceSet, tags, _, _ := fakeStackManager.CreateStackArgsForCall(0)
+						Expect(name).To(Equal("eksctl-my-cluster-addon-vpc-cni"))
+						Expect(resourceSet).NotTo(BeNil())
+						Expect(tags).To(Equal(map[string]string{
+							api.AddonNameTag: "vpc-cni",
+						}))
+						output, err := resourceSet.RenderJSON()
+						Expect(err).NotTo(HaveOccurred())
+						Expect(string(output)).To(ContainSubstring("arn:aws:iam::aws:policy/AmazonEKS_CNI_Policy"))
+						Expect(string(output)).To(ContainSubstring(":sub\":\"system:serviceaccount:kube-system:aws-node"))
+						Expect(*createAddonInput.ClusterName).To(Equal("my-cluster"))
+						Expect(*createAddonInput.AddonName).To(Equal("vpc-cni"))
+						Expect(*createAddonInput.AddonVersion).To(Equal("v1.0.0-eksbuild.1"))
+						Expect(*createAddonInput.ServiceAccountRoleArn).To(Equal("role-arn"))
+					})
+				})
+
+				Context("ipv6", func() {
+					BeforeEach(func() {
+						clusterConfig.VPC = api.NewClusterVPC()
+						clusterConfig.KubernetesNetworkConfig = &api.KubernetesNetworkConfig{
+							IPFamily: api.IPV6Family,
+						}
+					})
+
+					It("creates a role with the recommended policies and attaches it to the addon", func() {
+						err := manager.Create(&api.Addon{
+							Name:    "vpc-cni",
+							Version: "v1.0.0-eksbuild.1",
+						}, false)
+						Expect(err).NotTo(HaveOccurred())
+						Expect(fakeStackManager.CreateStackCallCount()).To(Equal(1))
+						name, resourceSet, tags, _, _ := fakeStackManager.CreateStackArgsForCall(0)
+						Expect(name).To(Equal("eksctl-my-cluster-addon-vpc-cni"))
+						Expect(resourceSet).NotTo(BeNil())
+						Expect(tags).To(Equal(map[string]string{
+							api.AddonNameTag: "vpc-cni",
+						}))
+						output, err := resourceSet.RenderJSON()
+						Expect(err).NotTo(HaveOccurred())
+						Expect(string(output)).To(ContainSubstring("AssignIpv6Addresses"))
+						Expect(*createAddonInput.ClusterName).To(Equal("my-cluster"))
+						Expect(*createAddonInput.AddonName).To(Equal("vpc-cni"))
+						Expect(*createAddonInput.AddonVersion).To(Equal("v1.0.0-eksbuild.1"))
+						Expect(*createAddonInput.ServiceAccountRoleArn).To(Equal("role-arn"))
+					})
 				})
 			})
 
-			When("its the aws-ebs-csi-driver addon", func() {
+			When("it's the aws-ebs-csi-driver addon", func() {
 				It("creates a role with the recommended policies and attaches it to the addon", func() {
 					err := manager.Create(&api.Addon{
 						Name:    "aws-ebs-csi-driver",
