@@ -37,7 +37,7 @@ var _ = Describe("Update", func() {
 		fakeStackManager = new(fakes.FakeStackManager)
 
 		oidc, err = iamoidc.NewOpenIDConnectManager(nil, "456123987123", "https://oidc.eks.us-west-2.amazonaws.com/id/A39A2842863C47208955D753DE205E6E", "aws", nil)
-		Expect(err).ToNot(HaveOccurred())
+		Expect(err).NotTo(HaveOccurred())
 		oidc.ProviderARN = "arn:aws:iam::456123987123:oidc-provider/oidc.eks.us-west-2.amazonaws.com/id/A39A2842863C47208955D753DE205E6E"
 		irsaManager = irsa.New("my-cluster", fakeStackManager, oidc, nil)
 	})
