@@ -590,6 +590,454 @@ var _ = Describe("ClusterConfig validation", func() {
 		})
 	})
 
+	Describe("ValidatePrivateCluster", func() {
+		var (
+			cfg *api.ClusterConfig
+			vpc *api.ClusterVPC
+		)
+
+		BeforeEach(func() {
+			cfg = api.NewClusterConfig()
+			vpc = api.NewClusterVPC()
+			cfg.VPC = vpc
+			cfg.PrivateCluster = &api.PrivateCluster{
+				Enabled: true,
+			}
+		})
+		When("private cluster is enabled", func() {
+			It("validates the config", func() {
+				err := cfg.ValidatePrivateCluster()
+				Expect(err).NotTo(HaveOccurred())
+			})
+		})
+		When("vpc is provided but no private subnets", func() {
+			It("fails the validation", func() {
+				cfg.VPC.Subnets = &api.ClusterSubnets{}
+				cfg.VPC.ID = "id"
+				err := cfg.ValidatePrivateCluster()
+				Expect(err).To(MatchError(ContainSubstring("vpc.subnets.private must be specified in a fully-private cluster when a pre-existing VPC is supplied")))
+			})
+		})
+		When("additional endpoints are defined with skip endpoints", func() {
+			It("fails the validation", func() {
+				cfg.PrivateCluster.AdditionalEndpointServices = []string{api.EndpointServiceCloudFormation}
+				cfg.PrivateCluster.SkipEndpointCreation = true
+				err := cfg.ValidatePrivateCluster()
+				Expect(err).To(MatchError(ContainSubstring("additionalEndpoints cannot be defined together with skipEndpointCreation set to true")))
+			})
+		})
+		When("additional endpoints are defined", func() {
+			It("validates the endpoint configuration", func() {
+				cfg.PrivateCluster.AdditionalEndpointServices = []string{api.EndpointServiceCloudFormation}
+				err := cfg.ValidatePrivateCluster()
+				Expect(err).NotTo(HaveOccurred())
+			})
+		})
+		When("additional endpoints are defined incorrectly", func() {
+			It("fails the endpoint validation", func() {
+				cfg.PrivateCluster.AdditionalEndpointServices = []string{"unknown"}
+				err := cfg.ValidatePrivateCluster()
+				Expect(err).To(MatchError(ContainSubstring("invalid value in privateCluster.additionalEndpointServices")))
+			})
+		})
+		When("private cluster is enabled with skip endpoints", func() {
+			It("does not fail the validation", func() {
+				cfg.PrivateCluster.SkipEndpointCreation = true
+				err := cfg.ValidatePrivateCluster()
+				Expect(err).NotTo(HaveOccurred())
+			})
+		})
+	})
+	Describe("network config", func() {
+		var (
+			cfg *api.ClusterConfig
+			vpc *api.ClusterVPC
+			err error
+		)
+
+		BeforeEach(func() {
+			cfg = api.NewClusterConfig()
+			vpc = api.NewClusterVPC()
+			cfg.VPC = vpc
+		})
+
+		Context("ipFamily", func() {
+			It("should not error default ipFamily setting", func() {
+				err = api.ValidateClusterConfig(cfg)
+				Expect(err).ToNot(HaveOccurred())
+				Expect(cfg.KubernetesNetworkConfig.IPFamily).To(Equal(api.IPV4Family))
+			})
+
+			When("ipFamily isn't IPv4 or IPv6", func() {
+				It("returns an error", func() {
+					cfg.KubernetesNetworkConfig.IPFamily = "invalid"
+					err = api.ValidateClusterConfig(cfg)
+					Expect(err).To(MatchError(ContainSubstring(`invalid value "invalid" for ipFamily; allowed are IPv4 and IPv6`)))
+				})
+			})
+
+			When("ipFamily is empty", func() {
+				It("treats it as IPv4 and does not return an error", func() {
+					cfg.KubernetesNetworkConfig.IPFamily = ""
+					Expect(api.ValidateClusterConfig(cfg)).To(Succeed())
+				})
+			})
+
+			When("ipFamily is set to IPv6", func() {
+				JustBeforeEach(func() {
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV6Family
+				})
+
+				It("accepts that setting", func() {
+					cfg.VPC.NAT = nil
+					cfg.VPC.IPv6Cidr = "foo"
+					cfg.VPC.IPv6Pool = "bar"
+					cfg.Addons = append(cfg.Addons,
+						&api.Addon{Name: api.KubeProxyAddon},
+						&api.Addon{Name: api.CoreDNSAddon},
+						&api.Addon{Name: api.VPCCNIAddon},
+					)
+					cfg.IAM = &api.ClusterIAM{
+						WithOIDC: api.Enabled(),
+					}
+					cfg.Metadata.Version = api.Version1_21
+					err = cfg.ValidateVPCConfig()
+					Expect(err).ToNot(HaveOccurred())
+					cfg.Metadata.Version = "1.31"
+					err = cfg.ValidateVPCConfig()
+					Expect(err).ToNot(HaveOccurred())
+				})
+
+				When("ipFamily is set to IPv6 but version is not or too low", func() {
+					It("returns an error", func() {
+						cfg.VPC.NAT = nil
+						cfg.Addons = append(cfg.Addons,
+							&api.Addon{Name: api.KubeProxyAddon},
+							&api.Addon{Name: api.CoreDNSAddon},
+							&api.Addon{Name: api.VPCCNIAddon},
+						)
+						cfg.IAM = &api.ClusterIAM{
+							WithOIDC: api.Enabled(),
+						}
+						cfg.Metadata.Version = ""
+						err = api.ValidateClusterConfig(cfg)
+						Expect(err).To(MatchError(ContainSubstring("failed to convert  cluster version to semver: unable to parse first version")))
+						cfg.Metadata.Version = api.Version1_12
+						err = api.ValidateClusterConfig(cfg)
+						Expect(err).To(MatchError(ContainSubstring("cluster version must be >= 1.21")))
+					})
+				})
+
+				When("ipFamily is set to IPv6 but no managed addons are provided", func() {
+					It("it returns an error including which addons are missing", func() {
+						cfg.VPC.NAT = nil
+						cfg.IAM = &api.ClusterIAM{
+							WithOIDC: api.Enabled(),
+						}
+						cfg.Addons = append(cfg.Addons, &api.Addon{Name: api.KubeProxyAddon})
+						err = api.ValidateClusterConfig(cfg)
+						Expect(err).To(MatchError(ContainSubstring("the default core addons must be defined for IPv6; missing addon(s): vpc-cni, coredns")))
+					})
+				})
+
+				When("the vpc-cni version is configured", func() {
+					When("the version of the vpc-cni is too low", func() {
+						It("returns an error", func() {
+							cfg.Metadata.Version = api.Version1_22
+							cfg.IAM = &api.ClusterIAM{
+								WithOIDC: api.Enabled(),
+							}
+							cfg.Addons = append(cfg.Addons,
+								&api.Addon{Name: api.KubeProxyAddon},
+								&api.Addon{Name: api.CoreDNSAddon},
+								&api.Addon{Name: api.VPCCNIAddon, Version: "1.9.0"},
+							)
+							cfg.VPC.NAT = nil
+							err = api.ValidateClusterConfig(cfg)
+							Expect(err).To(MatchError(ContainSubstring("vpc-cni version must be at least version 1.10.0 for IPv6")))
+						})
+					})
+
+					When("the version of the vpc-cni is supported", func() {
+						It("does not error", func() {
+							cfg.Metadata.Version = api.Version1_22
+							cfg.IAM = &api.ClusterIAM{
+								WithOIDC: api.Enabled(),
+							}
+							cfg.Addons = append(cfg.Addons,
+								&api.Addon{Name: api.KubeProxyAddon},
+								&api.Addon{Name: api.CoreDNSAddon},
+								&api.Addon{Name: api.VPCCNIAddon, Version: "1.10"},
+							)
+							cfg.VPC.NAT = nil
+							err = cfg.ValidateVPCConfig()
+							Expect(err).NotTo(HaveOccurred())
+						})
+					})
+
+					When("the version of the vpc-cni is not configured", func() {
+						It("does not error", func() {
+							cfg.Metadata.Version = api.Version1_22
+							cfg.IAM = &api.ClusterIAM{
+								WithOIDC: api.Enabled(),
+							}
+							cfg.Addons = append(cfg.Addons,
+								&api.Addon{Name: api.KubeProxyAddon},
+								&api.Addon{Name: api.CoreDNSAddon},
+								&api.Addon{Name: api.VPCCNIAddon},
+							)
+							cfg.VPC.NAT = nil
+							err = api.ValidateClusterConfig(cfg)
+							Expect(err).NotTo(HaveOccurred())
+							Expect(cfg.Addons[2].Version).To(Equal("1.10.0"))
+						})
+					})
+
+					When("the version of the vpc-cni is latest", func() {
+						It("does not error", func() {
+							cfg.Metadata.Version = api.Version1_22
+							cfg.IAM = &api.ClusterIAM{
+								WithOIDC: api.Enabled(),
+							}
+							cfg.Addons = append(cfg.Addons,
+								&api.Addon{Name: api.KubeProxyAddon},
+								&api.Addon{Name: api.CoreDNSAddon},
+								&api.Addon{Name: api.VPCCNIAddon, Version: "latest"},
+							)
+							cfg.VPC.NAT = nil
+							err = cfg.ValidateVPCConfig()
+							Expect(err).NotTo(HaveOccurred())
+						})
+					})
+
+					When("the version of the vpc-cni is invalid", func() {
+						It("it returns an error", func() {
+							cfg.Metadata.Version = api.Version1_22
+							cfg.IAM = &api.ClusterIAM{
+								WithOIDC: api.Enabled(),
+							}
+							cfg.Addons = append(cfg.Addons,
+								&api.Addon{Name: api.KubeProxyAddon},
+								&api.Addon{Name: api.CoreDNSAddon},
+								&api.Addon{Name: api.VPCCNIAddon, Version: "1.invalid!semver"},
+							)
+							cfg.VPC.NAT = nil
+							err = api.ValidateClusterConfig(cfg)
+							Expect(err).To(MatchError(ContainSubstring("failed to parse version")))
+						})
+					})
+				})
+
+				When("iam is not set", func() {
+					It("returns an error", func() {
+						cfg.Addons = append(cfg.Addons,
+							&api.Addon{Name: api.KubeProxyAddon},
+							&api.Addon{Name: api.CoreDNSAddon},
+							&api.Addon{Name: api.VPCCNIAddon},
+						)
+						err = api.ValidateClusterConfig(cfg)
+						Expect(err).To(MatchError(ContainSubstring("oidc needs to be enabled if IPv6 is set")))
+					})
+				})
+
+				When("iam is set but OIDC is disabled", func() {
+					It("returns an error", func() {
+						cfg.IAM = &api.ClusterIAM{
+							WithOIDC: api.Disabled(),
+						}
+						cfg.Addons = append(cfg.Addons,
+							&api.Addon{Name: api.KubeProxyAddon},
+							&api.Addon{Name: api.CoreDNSAddon},
+							&api.Addon{Name: api.VPCCNIAddon},
+						)
+						err = api.ValidateClusterConfig(cfg)
+						Expect(err).To(MatchError(ContainSubstring("oidc needs to be enabled if IPv6 is set")))
+					})
+				})
+
+				When("ipFamily is set to IPv6 and vpc.NAT is defined", func() {
+					It("it returns an error", func() {
+						cfg.Metadata.Version = api.Version1_22
+						cfg.IAM = &api.ClusterIAM{
+							WithOIDC: api.Enabled(),
+						}
+						cfg.Addons = append(cfg.Addons,
+							&api.Addon{Name: api.KubeProxyAddon},
+							&api.Addon{Name: api.CoreDNSAddon},
+							&api.Addon{Name: api.VPCCNIAddon},
+						)
+						cfg.VPC.NAT = &api.ClusterNAT{}
+						err = cfg.ValidateVPCConfig()
+						Expect(err).To(MatchError(ContainSubstring("setting NAT is not supported with IPv6")))
+					})
+				})
+
+				When("ipFamily is set to IPv6 and serviceIPv4CIDR is not empty", func() {
+					It("it returns an error", func() {
+						cfg.Metadata.Version = api.Version1_22
+						cfg.IAM = &api.ClusterIAM{
+							WithOIDC: api.Enabled(),
+						}
+						cfg.Addons = append(cfg.Addons,
+							&api.Addon{Name: api.KubeProxyAddon},
+							&api.Addon{Name: api.CoreDNSAddon},
+							&api.Addon{Name: api.VPCCNIAddon},
+						)
+						cfg.KubernetesNetworkConfig.ServiceIPv4CIDR = "192.168.0.0/24"
+						cfg.VPC.NAT = nil
+						err = api.ValidateClusterConfig(cfg)
+						Expect(err).To(MatchError(ContainSubstring("service ipv4 cidr is not supported with IPv6")))
+					})
+				})
+
+				When("ipFamily is set to IPv6 and AutoAllocateIPv6 is set", func() {
+					It("it returns an error", func() {
+						cfg.VPC.AutoAllocateIPv6 = api.Enabled()
+						cfg.Metadata.Version = api.Version1_22
+						cfg.IAM = &api.ClusterIAM{
+							WithOIDC: api.Enabled(),
+						}
+						cfg.Addons = append(cfg.Addons,
+							&api.Addon{Name: api.KubeProxyAddon},
+							&api.Addon{Name: api.CoreDNSAddon},
+							&api.Addon{Name: api.VPCCNIAddon},
+						)
+						cfg.VPC.NAT = nil
+						err = cfg.ValidateVPCConfig()
+						Expect(err).To(MatchError(ContainSubstring("auto allocate ipv6 is not supported with IPv6")))
+					})
+				})
+			})
+		})
+
+		Context("extraCIDRs", func() {
+			It("validates cidrs", func() {
+				cfg.VPC.ExtraCIDRs = []string{"192.168.0.0/24"}
+				cfg.VPC.PublicAccessCIDRs = []string{"3.48.58.68/24"}
+				err = cfg.ValidateVPCConfig()
+				Expect(err).ToNot(HaveOccurred())
+			})
+
+			When("extraCIDRs has an invalid cidr", func() {
+				It("returns an error", func() {
+					cfg.VPC.ExtraCIDRs = []string{"not-a-cidr"}
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(HaveOccurred())
+				})
+			})
+
+			When("public access cidrs has an invalid cidr", func() {
+				It("returns an error", func() {
+					cfg.VPC.PublicAccessCIDRs = []string{"48.58.68/24"}
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(HaveOccurred())
+				})
+			})
+		})
+
+		Context("ipv6 CIDRs", func() {
+			When("IPv6Cidr or IPv6CidrPool is provided and ipv6 is not set", func() {
+				It("returns an error", func() {
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV4Family
+					cfg.VPC.IPv6Cidr = "foo"
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(MatchError("Ipv6Cidr and Ipv6CidrPool are only supported when IPFamily is set to IPv6"))
+
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV4Family
+					cfg.VPC.IPv6Cidr = ""
+					cfg.VPC.IPv6Pool = "bar"
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(MatchError("Ipv6Cidr and Ipv6CidrPool are only supported when IPFamily is set to IPv6"))
+				})
+			})
+
+			When("only one of IPv6Cidr or IPv6CidrPool is provided and ipv6 is set", func() {
+				It("returns an error", func() {
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV6Family
+					cfg.VPC.IPv6Cidr = "foo"
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(MatchError("Ipv6Cidr and Ipv6Pool must both be configured to use a custom IPv6 CIDR and address pool"))
+
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV6Family
+					cfg.VPC.IPv6Cidr = ""
+					cfg.VPC.IPv6Pool = "bar"
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(MatchError("Ipv6Cidr and Ipv6Pool must both be configured to use a custom IPv6 CIDR and address pool"))
+				})
+			})
+
+			When("it's set alongside VPC.ID", func() {
+				It("returns an error", func() {
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV6Family
+					cfg.VPC.IPv6Cidr = "foo"
+					cfg.VPC.IPv6Pool = "bar"
+					cfg.VPC.ID = "123"
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(MatchError("cannot provide VPC.IPv6Cidr when using a pre-existing VPC.ID"))
+				})
+			})
+		})
+
+		Context("extraIPv6CIDRs", func() {
+			It("validates cidrs", func() {
+				cfg.KubernetesNetworkConfig.IPFamily = api.IPV6Family
+				cfg.Metadata.Version = api.LatestVersion
+				cfg.Addons = append(cfg.Addons,
+					&api.Addon{Name: api.KubeProxyAddon},
+					&api.Addon{Name: api.CoreDNSAddon},
+					&api.Addon{Name: api.VPCCNIAddon},
+				)
+				cfg.IAM = &api.ClusterIAM{
+					WithOIDC: api.Enabled(),
+				}
+				cfg.VPC.ExtraIPv6CIDRs = []string{"2002::1234:abcd:ffff:c0a8:101/64"}
+				cfg.VPC.NAT = nil
+				err = cfg.ValidateVPCConfig()
+				Expect(err).ToNot(HaveOccurred())
+			})
+
+			When("extraIPv6CIDRs has an invalid cidr", func() {
+				It("returns an error", func() {
+					cfg.VPC.ExtraIPv6CIDRs = []string{"not-a-cidr"}
+					cfg.Metadata.Version = api.LatestVersion
+					cfg.Addons = append(cfg.Addons,
+						&api.Addon{Name: api.KubeProxyAddon},
+						&api.Addon{Name: api.CoreDNSAddon},
+						&api.Addon{Name: api.VPCCNIAddon},
+					)
+					cfg.IAM = &api.ClusterIAM{
+						WithOIDC: api.Enabled(),
+					}
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV6Family
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(HaveOccurred())
+
+					cfg.VPC.ExtraIPv6CIDRs = []string{"2002::1234:abcd:ffff:c0a8:101/644"}
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(HaveOccurred())
+				})
+			})
+
+			When("when ipv4 is configured", func() {
+				It("returns an error", func() {
+					cfg.KubernetesNetworkConfig.IPFamily = api.IPV4Family
+					cfg.Metadata.Version = api.LatestVersion
+					cfg.Addons = append(cfg.Addons,
+						&api.Addon{Name: api.KubeProxyAddon},
+						&api.Addon{Name: api.CoreDNSAddon},
+						&api.Addon{Name: api.VPCCNIAddon},
+					)
+					cfg.IAM = &api.ClusterIAM{
+						WithOIDC: api.Enabled(),
+					}
+					cfg.VPC.ExtraIPv6CIDRs = []string{"2002::1234:abcd:ffff:c0a8:101/644"}
+					err = cfg.ValidateVPCConfig()
+					Expect(err).To(MatchError("cannot specify vpc.extraIPv6CIDRs with an IPv4 cluster"))
+				})
+			})
+		})
+	})
+
 	Describe("ValidatePrivateCluster", func() {
 		var (
 			cfg *api.ClusterConfig
