@@ -1,9 +1,5 @@
 package fakes
 
-import (
-	cfn "github.com/aws/aws-sdk-go/service/cloudformation"
-)
-
 type FakeTemplate struct {
 	Description string
 	Resources   map[string]struct {
@@ -13,7 +9,7 @@ type FakeTemplate struct {
 		UpdatePolicy map[string]map[string]interface{}
 	}
 	Mappings map[string]interface{}
-	Outputs  map[string]cfn.Output
+	Outputs  interface{}
 }
 
 type Tag struct {
@@ -24,13 +20,14 @@ type Tag struct {
 }
 
 type Properties struct {
-	GroupDescription           string
-	Description                string
-	Tags                       []Tag
-	SecurityGroupIngress       []SGIngress
-	GroupID                    interface{}
-	SourceSecurityGroupID      interface{}
-	DestinationSecurityGroupID interface{}
+	EnableDNSHostnames, EnableDNSSupport bool
+	GroupDescription                     string
+	Description                          string
+	Tags                                 []Tag
+	SecurityGroupIngress                 []SGIngress
+	GroupID                              interface{}
+	SourceSecurityGroupID                interface{}
+	DestinationSecurityGroupID           interface{}
 
 	Path, RoleName           string
 	Roles, ManagedPolicyArns []interface{}
@@ -60,19 +57,23 @@ type Properties struct {
 	TargetGroupARNs                   []string
 	DesiredCapacity, MinSize, MaxSize string
 
-	CidrIP, CidrIpv6, IPProtocol string
+	CidrIP, CidrIPv6, IPProtocol string
 	FromPort, ToPort             int
 
-	VpcID, SubnetID                            interface{}
-	RouteTableID, AllocationID                 interface{}
-	GatewayID, InternetGatewayID, NatGatewayID interface{}
-	DestinationCidrBlock                       interface{}
-	MapPublicIPOnLaunch                        bool
+	VpcID, SubnetID                                         interface{}
+	EgressOnlyInternetGatewayID, RouteTableID, AllocationID interface{}
+	GatewayID, InternetGatewayID, NatGatewayID              interface{}
+	DestinationCidrBlock, DestinationIpv6CidrBlock          interface{}
+	MapPublicIPOnLaunch                                     bool
+	AssignIpv6AddressOnCreation                             *bool
 
-	Ipv6CidrBlock map[string][]interface{}
+	Ipv6CidrBlock           interface{}
+	Ipv6Pool                string
+	CidrBlock               interface{}
+	KubernetesNetworkConfig KubernetesNetworkConfig
 
-	AmazonProvidedIpv6CidrBlock         bool
-	AvailabilityZone, Domain, CidrBlock string
+	AmazonProvidedIpv6CidrBlock bool
+	AvailabilityZone, Domain    string
 
 	Name, Version      string
 	RoleArn            interface{}
@@ -113,6 +114,12 @@ type Properties struct {
 	}
 }
 
+type KubernetesNetworkConfig struct {
+	ServiceIPv4CIDR string
+	ServiceIPv6CIDR interface{}
+	IPFamily        string
+}
+
 type SGIngress struct {
 	SourceSecurityGroupID interface{}
 	FromPort              float64
